---
Summary: Format cards referenced in other cards
Status: Done
---

# Description

Idea is that if you've got `[[card01]]` in your card, `scard`, `sbl`, `sboard` etc will add additional data as configured.

By default, it will return `index - summary [status] (assignee)`.
